@@ -1,7 +1,7 @@
 /*
  *  Ball And Paddle
  *
- *  Copyright (C) 2007 by Eric Hutchins
+ *  Copyright (C) 2007, 2008 by Eric Hutchins
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,9 +45,9 @@ public:
   void cleanup ();
   void pause ();
   void resume ();
-  void handleEvents (GameStateManager * gameStateManager);
-  void draw (GameStateManager * gameStateManager);
-  void update (GameStateManager * gameStateManager);
+  void handleEvents ();
+  void draw (SDL_Surface *dest);
+  void update ();
   bool getTransitioning ()
   {
     return false;
