@@ -1,7 +1,7 @@
 /*
  *  Ball And Paddle
  *
- *  Copyright (C) 2007 by Eric Hutchins
+ *  Copyright (C) 2007, 2008 by Eric Hutchins
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,18 @@
 #define __LASER_H__
 
 #include <vector>
+#include <map>
 using namespace std;
 
+#include <libguile.h>
+
 #include "SDL.h"
 
+#include "blocktype.h"
 #include "block.h"
 #include "powerup.h"
+#include "utilities.h"
+#include "soundmanager.h"
 
 class Laser
 {
@@ -34,13 +40,18 @@ class Laser
   double y;
   int width;
   int height;
+  int field_width;
+  int field_height;
   SDL_Surface *imgLaser;
   bool alive;
 public:
-    Laser (int x, int y, int width, int height, SDL_Surface * imgLaser);
+  static Laser *current;
+    Laser (int x, int y, int width, int height, 
+           int field_width, int field_height, SDL_Surface * imgLaser);
    ~Laser ();
   void draw (SDL_Surface * dest);
-  void update (int time, vector < vector < Block * > >blocks,
+  void update (int time, map < string, BlockType * > block_palette, 
+               vector < Block * >blocks,
 	       vector < PowerUp * >&powerUps, int &score);
   bool isAlive ()
   {
