@@ -1,7 +1,7 @@
 /*
  *  Ball And Paddle
  *
- *  Copyright (C) 2007 by Eric Hutchins
+ *  Copyright (C) 2007, 2008 by Eric Hutchins
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@ using namespace std;
 
 #include "globals.h"
 #include "gamestate.h"
+#include "settingsmanager.h"
 
 class OptionsMenu:public GameState
 {
@@ -37,7 +38,7 @@ class OptionsMenu:public GameState
   SDL_Surface *imgBackground;
   int spacing;
 
-  void handleItem (GameStateManager * gameStateManager);
+  void handleItem ();
 
   static OptionsMenu m_instance;
 
@@ -50,9 +51,9 @@ public:
   void cleanup ();
   void pause ();
   void resume ();
-  void handleEvents (GameStateManager * gameStateManager);
-  void update (GameStateManager * gameStateManager);
-  void draw (GameStateManager * gameStateManager);
+  void handleEvents ();
+  void update ();
+  void draw (SDL_Surface *dest);
   bool getTransitioning ()
   {
     return false;
